/*
Utilitaire pour la synthèse vocale :
	- inspiré du tutoriel http://monwebfacile.free.fr/Tutoriaux/Javascript/JVS_SyntheseVocale.php
	

Instructions pour l'utiliser (voir demo_son2.html par exemple) :

	<button type="button" onclick="startToRecognize()">Son</button>		// à chaque nouvelle commande vocale 
	<button type="button" onclick="stopToRecognize()">Fin son</button>  // pour forcer la fin de la reconnaissance si nécessaire
	<pre id="informations"></pre> (facultatif)
	
	instanciation(); // instanciation du dispositif de reconnaissance (doit être une fois pour que 
	function interpreterVoix(transcript) { // fonction à définir, pour qu'elle interprète le texte reconnu
		...
	}

*/
		
			// -------------------
			// Variables générales
			// -------------------
			var recognition;
			var final_transcript = "";
			var currentContinuous;
			var currentInterimResults;
			var currentLang = 'fr-FR';
			
			var recognizing = false; // Reconnaissance en cours
			var compatibilite = false;
			
			// Instanciation
			// --------------
			function instanciation(){
				if (!('webkitSpeechRecognition' in window)) {
					displayInfo("Pas de reconnaissance vocale pour votre navigateur");
					compatibilite = false;
					return false;
				}
				else {
					compatibilite = true;
					displayInfo("Reconnaissance vocale (webkitSpeechRecognition) OK");
					recognition = new webkitSpeechRecognition();
					return true;
				}
			}
			// ---------------------
			// Fonctions principales
			// ---------------------
			
			// Initialisation de l'objet
			// -------------------------
			function setParam(_continuous,_interimResults,_lang){
				if(!recognition) {return;}
				recognition.continuous = _continuous;  
				recognition.interimResults = _interimResults;
				try {
					recognition.lang = _lang;
				}
				catch(e) {
				}			
			}
			
			// Gestion des évènements
			// ----------------------
			function initEvents(){
			
			    recognition.onstart = function() {
					displayInfo("Reconnaissance vocale : reçu évènement onstart");
					recognizing = true;
				}  
				
				recognition.onerror = function(event) {
					recognizing = false;
					displayInfo("Reconnaissance vocale : reçu évènement onerror (" + event.error +")");
				}  
				
				recognition.onend = function() {
					displayInfo("Reconnaissance vocale : reçu évènement onend");
					recognizing = false;
				} 
				
				recognition.abord = function() {
					displayInfo("Reconnaissance vocale : reçu évènement onabord");
					recognizing = false;
				} 
 		  
				recognition.onresult = function(event) {
					displayInfo("Reconnaissance vocale : reçu évènement onresult");
					if (typeof(event.results) == 'undefined') {
						recognition.onend = null;
						recognizing = false;
						recognition.stop();
						return;
					}					
					for (var i = event.resultIndex; i < event.results.length; ++i) {  
						if (event.results[i].isFinal) {  
							//final_transcript += "\n" + event.results[i][0].transcript;  
							interpreterVoix(event.results[i][0].transcript);
							recognizing = false;
							recognition.stop();
						} else {  
							//interim_transcript += "\n" + event.results[i][0].transcript;  
						}  
					} 
				} 				
			}  
			
			// 
			// ----------------------
			function startToRecognize(){
				if(!compatibilite) {
					displayInfo("Navigateur non compatible");
					return;
				}
				if(recognizing){
					displayInfo("Reconnaissance déjà en cours...");
					return;
				}
				setParam(true,true,currentLang);
				initEvents();
				
				if(!recognition) confirm("coucou");
				else recognition.start();
			}
			
			// 
			// ----------------------
			function stopToRecognize(){
				if(!compatibilite) return;
				if(!recognizing) return;
				recognizing = false;
				recognition.stop();
			}
			
			// 
			// ----------------------
			function abordToRecognize(){
				if(!compatibilite) return;
				if(!recognizing) return;
				recognizing = false;
				recognition.abord();
				//stopToRecognize();
			}

			
		// -------------------------------------------------------------------------------
		// -------------------------------------------------------------------------------	
			
			// Affichage des informations
			// --------------------------
			function displayInfo(_info,_id){
				_id = _id || 'informations';
				var x = document.getElementById(_id);
				if (x==null) return;;
				x.innerHTML = _info; 
			}
